==> fwbuilder_5.0.0.orig.tar.gz: fwbuilder-5.0.0.3568/src/libfwbuilder/src/fwbuilder/ServiceGroup.cpp <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id$


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#include <fwbuilder/libfwbuilder-config.h>

#include <fwbuilder/Service.h>
#include <fwbuilder/ServiceGroup.h>
#include <fwbuilder/FWServiceReference.h>
#include <fwbuilder/FWObjectDatabase.h>
#include <fwbuilder/ObjectGroup.h>
#include <fwbuilder/FWObjectReference.h>
#include <fwbuilder/Address.h>
#include <fwbuilder/Interval.h>

#include <fwbuilder/IPService.h>
#include <fwbuilder/ICMPService.h>
#include <fwbuilder/ICMP6Service.h>
#include <fwbuilder/TCPService.h>
#include <fwbuilder/UDPService.h>
#include <fwbuilder/CustomService.h>
#include <fwbuilder/TagService.h>
#include <fwbuilder/UserService.h>
#include <fwbuilder/FWServiceReference.h>
#include <fwbuilder/RuleSet.h>

#include <iostream>

using namespace std;
using namespace libfwbuilder;

const char *ServiceGroup::TYPENAME={"ServiceGroup"};

ServiceGroup::ServiceGroup() : Group() {}
ServiceGroup::~ServiceGroup() {}

bool  ServiceGroup::validateChild(FWObject *o)
{ 
    if (FWServiceReference::cast(o)!=NULL) return true;

    return (FWObject::validateChild(o) && 
            Address::cast(o)==NULL &&
            ObjectGroup::cast(o)==NULL &&
            Interval::cast(o)==NULL &&
            FWObjectReference::cast(o)==NULL &&
            RuleSet::cast(o)==NULL);
}

FWReference* ServiceGroup::createRef()
{
//    FWServiceReference *ref=new FWServiceReference();
    FWServiceReference *ref = getRoot()->createFWServiceReference();
    ref->setPointer(this);
    return ref;
}

xmlNodePtr ServiceGroup::toXML(xmlNodePtr parent) throw(FWException)
{
    xmlNodePtr me = FWObject::toXML(parent, false);
    xmlNewProp(me, TOXMLCAST("name"), STRTOXMLCAST(getName()));
    xmlNewProp(me, TOXMLCAST("comment"), STRTOXMLCAST(getComment()));
    xmlNewProp(me, TOXMLCAST("ro"), TOXMLCAST(((getRO()) ? "True" : "False")));

    for(list<FWObject*>::const_iterator j=begin(); j!=end(); ++j)
        (*j)->toXML(me);

    return me;
}

void ServiceGroup::getAllowedTypesOfChildren(std::list<std::string> &types_list)
{
    types_list.clear();
    types_list.push_back(IPService::TYPENAME);
    types_list.push_back(ICMPService::TYPENAME);
    types_list.push_back(ICMP6Service::TYPENAME);
    types_list.push_back(TCPService::TYPENAME);
    types_list.push_back(UDPService::TYPENAME);
    types_list.push_back(CustomService::TYPENAME);
    types_list.push_back(TagService::TYPENAME);
    types_list.push_back(UserService::TYPENAME);
    types_list.push_back(FWServiceReference::TYPENAME);
}

==> fwbuilder_5.1.0.orig.tar.gz: fwbuilder-5.1.0.3599/src/libfwbuilder/src/fwbuilder/ServiceGroup.cpp <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@fwbuilder.org

  $Id$


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#include "config.h"
#include "fwbuilder/libfwbuilder-config.h"


#include "fwbuilder/Service.h"
#include "fwbuilder/ServiceGroup.h"
#include "fwbuilder/FWServiceReference.h"
#include "fwbuilder/FWObjectDatabase.h"
#include "fwbuilder/ObjectGroup.h"
#include "fwbuilder/FWObjectReference.h"
#include "fwbuilder/Address.h"
#include "fwbuilder/Interval.h"

#include "fwbuilder/IPService.h"
#include "fwbuilder/ICMPService.h"
#include "fwbuilder/ICMP6Service.h"
#include "fwbuilder/TCPService.h"
#include "fwbuilder/UDPService.h"
#include "fwbuilder/CustomService.h"
#include "fwbuilder/TagService.h"
#include "fwbuilder/UserService.h"
#include "fwbuilder/FWServiceReference.h"
#include "fwbuilder/RuleSet.h"

#include <iostream>

using namespace std;
using namespace libfwbuilder;

const char *ServiceGroup::TYPENAME={"ServiceGroup"};

ServiceGroup::ServiceGroup() : Group() {}
ServiceGroup::~ServiceGroup() {}

bool  ServiceGroup::validateChild(FWObject *o)
{ 
    if (FWServiceReference::cast(o)!=NULL) return true;

    return (FWObject::validateChild(o) && 
            Address::cast(o)==NULL &&
            ObjectGroup::cast(o)==NULL &&
            Interval::cast(o)==NULL &&
            FWObjectReference::cast(o)==NULL &&
            RuleSet::cast(o)==NULL);
}

FWReference* ServiceGroup::createRef()
{
//    FWServiceReference *ref=new FWServiceReference();
    FWServiceReference *ref = getRoot()->createFWServiceReference();
    ref->setPointer(this);
    return ref;
}

xmlNodePtr ServiceGroup::toXML(xmlNodePtr parent) throw(FWException)
{
    xmlNodePtr me = FWObject::toXML(parent, false);
    xmlNewProp(me, TOXMLCAST("name"), STRTOXMLCAST(getName()));
    xmlNewProp(me, TOXMLCAST("comment"), STRTOXMLCAST(getComment()));
    xmlNewProp(me, TOXMLCAST("ro"), TOXMLCAST(((getRO()) ? "True" : "False")));

    for(list<FWObject*>::const_iterator j=begin(); j!=end(); ++j)
        (*j)->toXML(me);

    return me;
}

void ServiceGroup::getAllowedTypesOfChildren(std::list<std::string> &types_list)
{
    types_list.clear();
    types_list.push_back(IPService::TYPENAME);
    types_list.push_back(ICMPService::TYPENAME);
    types_list.push_back(ICMP6Service::TYPENAME);
    types_list.push_back(TCPService::TYPENAME);
    types_list.push_back(UDPService::TYPENAME);
    types_list.push_back(CustomService::TYPENAME);
    types_list.push_back(TagService::TYPENAME);
    types_list.push_back(UserService::TYPENAME);
    types_list.push_back(FWServiceReference::TYPENAME);
}
